@@ -1687,6 +1687,23 @@ def checkDigestFile(digestfile):
     return result
 
 
+def getParentPids(pid):
+    """
+    Получить ID всех родительских процессов
+    """
+    pid = str(pid)
+    while pid != "0":
+        statFile = "/proc/%s/stat" % pid
+        try:
+            data = readFile(statFile).split()
+            if len(data) > 4:
+                pid = data[3]
+                yield pid
+                continue
+        except (OSError,IOError) as e:
+            pass
+        break
+
 def getRunCommands(not_chroot=False, chroot=None, uid=None, withpid=False,
     with_lxc=False):
     """List run program"""
