@@ -845,7 +845,7 @@ class VariableClTemplateWrongPatch(Variable):
     """
     type = "choice"
 
-    value = "break"
+    value = "warning"
 
     def choice(self):
         return [("warning", _("Show warning")),
